# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/team_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#fsai_grpc_api/protos/team_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xc4\x01\n\x04Team\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\x05\"(\n\x11\x43reateTeamRequest\x12\x13\n\x04team\x18\x01 \x01(\x0b\x32\x05.Team\"K\n\x12\x43reateTeamResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04team\x18\x02 \x01(\x0b\x32\x05.Team2@\n\x07TeamApi\x12\x35\n\nCreateTeam\x12\x12.CreateTeamRequest\x1a\x13.CreateTeamResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Team.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Team.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Team.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Team.updated_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='Team.deleted_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='Team.created_by', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=303,
)


_CREATETEAMREQUEST = _descriptor.Descriptor(
  name='CreateTeamRequest',
  full_name='CreateTeamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='team', full_name='CreateTeamRequest.team', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=345,
)


_CREATETEAMRESPONSE = _descriptor.Descriptor(
  name='CreateTeamResponse',
  full_name='CreateTeamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CreateTeamResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='team', full_name='CreateTeamResponse.team', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=422,
)

_TEAM.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAM.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEAM.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATETEAMREQUEST.fields_by_name['team'].message_type = _TEAM
_CREATETEAMRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CREATETEAMRESPONSE.fields_by_name['team'].message_type = _TEAM
DESCRIPTOR.message_types_by_name['Team'] = _TEAM
DESCRIPTOR.message_types_by_name['CreateTeamRequest'] = _CREATETEAMREQUEST
DESCRIPTOR.message_types_by_name['CreateTeamResponse'] = _CREATETEAMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), {
  'DESCRIPTOR' : _TEAM,
  '__module__' : 'fsai_grpc_api.protos.team_api_pb2'
  # @@protoc_insertion_point(class_scope:Team)
  })
_sym_db.RegisterMessage(Team)

CreateTeamRequest = _reflection.GeneratedProtocolMessageType('CreateTeamRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETEAMREQUEST,
  '__module__' : 'fsai_grpc_api.protos.team_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateTeamRequest)
  })
_sym_db.RegisterMessage(CreateTeamRequest)

CreateTeamResponse = _reflection.GeneratedProtocolMessageType('CreateTeamResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETEAMRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.team_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateTeamResponse)
  })
_sym_db.RegisterMessage(CreateTeamResponse)



_TEAMAPI = _descriptor.ServiceDescriptor(
  name='TeamApi',
  full_name='TeamApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=424,
  serialized_end=488,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTeam',
    full_name='TeamApi.CreateTeam',
    index=0,
    containing_service=None,
    input_type=_CREATETEAMREQUEST,
    output_type=_CREATETEAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEAMAPI)

DESCRIPTOR.services_by_name['TeamApi'] = _TEAMAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/detection_instance_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import detection_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__api__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/detection_instance_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1fsai_grpc_api/protos/detection_instance_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(fsai_grpc_api/protos/detection_api.proto\x1a fsai_grpc_api/protos/utils.proto\"\xf4\x03\n\x11\x44\x65tectionInstance\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\x05\x12\x0f\n\x07part_id\x18\x03 \x01(\x05\x12\x10\n\x08image_id\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x65tection_id\x18\x05 \x01(\x05\x12\x11\n\tsource_id\x18\x06 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x07 \x01(\x0b\x32\x08.GeoBbox\x12\r\n\x05score\x18\x08 \x01(\x02\x12\x0e\n\x06height\x18\t \x01(\x02\x12/\n\x0b\x64\x65tected_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x63\x61tegory_id\x18\x0e \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x0f \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x10 \x01(\x0b\x32\t.GeoPoint\x12\r\n\x05state\x18\x11 \x01(\t\"?\n+CacheDetectionInstancesDataByImageIdRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"\x81\x01\n,CacheDetectionInstancesDataByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"}\n,FindOrCreateDetectionInstanceViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x81\x01\n-FindOrCreateDetectionInstanceViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\x7f\n.FindOrCreateDetectionInstanceViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"\x83\x01\n/FindOrCreateDetectionInstanceViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"W\n%GetDetectionInstancesByImageIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"{\n&GetDetectionInstancesByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"_\n-UpdateDetectionInstanceGeoBboxViaHumanRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x82\x01\n.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"a\n/UpdateDetectionInstanceGeoBboxViaMachineRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"\x84\x01\n0UpdateDetectionInstanceGeoBboxViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"T\n\"DeleteDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n#DeleteDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceDataByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"M\n$GetDetectionInstanceDataByIdResponse\x12%\n\x1d\x64\x65tection_instance_data_bytes\x18\x01 \x01(\x0c\"j\n\'TransitionDetectionInstanceStateRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\x12\x0f\n\x07trigger\x18\x02 \x01(\t\"\x8b\x01\n(TransitionDetectionInstanceStateResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05state\x18\x02 \x01(\t\x12.\n\x12\x64\x65tection_instance\x18\x03 \x01(\x0b\x32\x12.DetectionInstance\"U\n#GetDetectionInstanceBboxByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"w\n$GetDetectionInstanceBboxByIdResponse\x12\r\n\x05min_x\x18\x01 \x01(\x05\x12\r\n\x05max_x\x18\x02 \x01(\x05\x12\r\n\x05min_y\x18\x03 \x01(\x05\x12\r\n\x05max_y\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x05 \x01(\x05\"V\n$GetDetectionInstanceStateByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"y\n%GetDetectionInstanceStateByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"Q\n\x1fGetDetectionInstanceByIdRequest\x12.\n\x12\x64\x65tection_instance\x18\x01 \x01(\x0b\x32\x12.DetectionInstance\"t\n GetDetectionInstanceByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa4\x01\n/UpdateDetectionInstanceGeoPointsViaHumanRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x84\x01\n0UpdateDetectionInstanceGeoPointsViaHumanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance\"\xa6\x01\n1UpdateDetectionInstanceGeoPointsViaMachineRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\x12)\n\x16geo_point_shadow_start\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\'\n\x14geo_point_shadow_end\x18\x03 \x01(\x0b\x32\t.GeoPoint\"\x86\x01\n2UpdateDetectionInstanceGeoPointsViaMachineResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12.\n\x12\x64\x65tection_instance\x18\x02 \x01(\x0b\x32\x12.DetectionInstance2\xff\r\n\x14\x44\x65tectionInstanceApi\x12\x83\x01\n$CacheDetectionInstancesDataByImageId\x12,.CacheDetectionInstancesDataByImageIdRequest\x1a-.CacheDetectionInstancesDataByImageIdResponse\x12h\n\x1b\x44\x65leteDetectionInstanceById\x12#.DeleteDetectionInstanceByIdRequest\x1a$.DeleteDetectionInstanceByIdResponse\x12\x86\x01\n%FindOrCreateDetectionInstanceViaHuman\x12-.FindOrCreateDetectionInstanceViaHumanRequest\x1a..FindOrCreateDetectionInstanceViaHumanResponse\x12\x8c\x01\n\'FindOrCreateDetectionInstanceViaMachine\x12/.FindOrCreateDetectionInstanceViaMachineRequest\x1a\x30.FindOrCreateDetectionInstanceViaMachineResponse\x12m\n\x1cGetDetectionInstanceDataById\x12$.GetDetectionInstanceDataByIdRequest\x1a%.GetDetectionInstanceDataByIdResponse0\x01\x12k\n\x1cGetDetectionInstanceBboxById\x12$.GetDetectionInstanceBboxByIdRequest\x1a%.GetDetectionInstanceBboxByIdResponse\x12n\n\x1dGetDetectionInstanceStateById\x12%.GetDetectionInstanceStateByIdRequest\x1a&.GetDetectionInstanceStateByIdResponse\x12_\n\x18GetDetectionInstanceById\x12 .GetDetectionInstanceByIdRequest\x1a!.GetDetectionInstanceByIdResponse\x12q\n\x1eGetDetectionInstancesByImageId\x12&.GetDetectionInstancesByImageIdRequest\x1a\'.GetDetectionInstancesByImageIdResponse\x12w\n TransitionDetectionInstanceState\x12(.TransitionDetectionInstanceStateRequest\x1a).TransitionDetectionInstanceStateResponse\x12\x89\x01\n&UpdateDetectionInstanceGeoBboxViaHuman\x12..UpdateDetectionInstanceGeoBboxViaHumanRequest\x1a/.UpdateDetectionInstanceGeoBboxViaHumanResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoBboxViaMachine\x12\x30.UpdateDetectionInstanceGeoBboxViaMachineRequest\x1a\x31.UpdateDetectionInstanceGeoBboxViaMachineResponse\x12\x8f\x01\n(UpdateDetectionInstanceGeoPointsViaHuman\x12\x30.UpdateDetectionInstanceGeoPointsViaHumanRequest\x1a\x31.UpdateDetectionInstanceGeoPointsViaHumanResponse\x12\x95\x01\n*UpdateDetectionInstanceGeoPointsViaMachine\x12\x32.UpdateDetectionInstanceGeoPointsViaMachineRequest\x1a\x33.UpdateDetectionInstanceGeoPointsViaMachineResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_detection__api__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_DETECTIONINSTANCE = _descriptor.Descriptor(
  name='DetectionInstance',
  full_name='DetectionInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DetectionInstance.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='DetectionInstance.workflow_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='part_id', full_name='DetectionInstance.part_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='DetectionInstance.image_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_id', full_name='DetectionInstance.detection_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_id', full_name='DetectionInstance.source_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='DetectionInstance.geo_bbox', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='DetectionInstance.score', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='DetectionInstance.height', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detected_at', full_name='DetectionInstance.detected_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='DetectionInstance.created_at', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='DetectionInstance.updated_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='DetectionInstance.deleted_at', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='DetectionInstance.category_id', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='DetectionInstance.geo_point_shadow_start', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='DetectionInstance.geo_point_shadow_end', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='DetectionInstance.state', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=663,
)


_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByImageIdRequest',
  full_name='CacheDetectionInstancesDataByImageIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='CacheDetectionInstancesDataByImageIdRequest.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=728,
)


_CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE = _descriptor.Descriptor(
  name='CacheDetectionInstancesDataByImageIdResponse',
  full_name='CacheDetectionInstancesDataByImageIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CacheDetectionInstancesDataByImageIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='CacheDetectionInstancesDataByImageIdResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=860,
)


_FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceViaHumanRequest',
  full_name='FindOrCreateDetectionInstanceViaHumanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceViaHumanRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection', full_name='FindOrCreateDetectionInstanceViaHumanRequest.detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=987,
)


_FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceViaHumanResponse',
  full_name='FindOrCreateDetectionInstanceViaHumanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateDetectionInstanceViaHumanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceViaHumanResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1119,
)


_FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceViaMachineRequest',
  full_name='FindOrCreateDetectionInstanceViaMachineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceViaMachineRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection', full_name='FindOrCreateDetectionInstanceViaMachineRequest.detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1248,
)


_FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE = _descriptor.Descriptor(
  name='FindOrCreateDetectionInstanceViaMachineResponse',
  full_name='FindOrCreateDetectionInstanceViaMachineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateDetectionInstanceViaMachineResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='FindOrCreateDetectionInstanceViaMachineResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1382,
)


_GETDETECTIONINSTANCESBYIMAGEIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstancesByImageIdRequest',
  full_name='GetDetectionInstancesByImageIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstancesByImageIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1384,
  serialized_end=1471,
)


_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstancesByImageIdResponse',
  full_name='GetDetectionInstancesByImageIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetDetectionInstancesByImageIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instances', full_name='GetDetectionInstancesByImageIdResponse.detection_instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1596,
)


_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxViaHumanRequest',
  full_name='UpdateDetectionInstanceGeoBboxViaHumanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxViaHumanRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1693,
)


_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxViaHumanResponse',
  full_name='UpdateDetectionInstanceGeoBboxViaHumanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoBboxViaHumanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxViaHumanResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1696,
  serialized_end=1826,
)


_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxViaMachineRequest',
  full_name='UpdateDetectionInstanceGeoBboxViaMachineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxViaMachineRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1828,
  serialized_end=1925,
)


_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoBboxViaMachineResponse',
  full_name='UpdateDetectionInstanceGeoBboxViaMachineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoBboxViaMachineResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoBboxViaMachineResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1928,
  serialized_end=2060,
)


_DELETEDETECTIONINSTANCEBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdRequest',
  full_name='DeleteDetectionInstanceByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2146,
)


_DELETEDETECTIONINSTANCEBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteDetectionInstanceByIdResponse',
  full_name='DeleteDetectionInstanceByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteDetectionInstanceByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='DeleteDetectionInstanceByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2148,
  serialized_end=2267,
)


_GETDETECTIONINSTANCEDATABYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdRequest',
  full_name='GetDetectionInstanceDataByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceDataByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2269,
  serialized_end=2354,
)


_GETDETECTIONINSTANCEDATABYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceDataByIdResponse',
  full_name='GetDetectionInstanceDataByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_data_bytes', full_name='GetDetectionInstanceDataByIdResponse.detection_instance_data_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2433,
)


_TRANSITIONDETECTIONINSTANCESTATEREQUEST = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateRequest',
  full_name='TransitionDetectionInstanceStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='TransitionDetectionInstanceStateRequest.trigger', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2435,
  serialized_end=2541,
)


_TRANSITIONDETECTIONINSTANCESTATERESPONSE = _descriptor.Descriptor(
  name='TransitionDetectionInstanceStateResponse',
  full_name='TransitionDetectionInstanceStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TransitionDetectionInstanceStateResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='TransitionDetectionInstanceStateResponse.state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='TransitionDetectionInstanceStateResponse.detection_instance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2683,
)


_GETDETECTIONINSTANCEBBOXBYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdRequest',
  full_name='GetDetectionInstanceBboxByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceBboxByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2685,
  serialized_end=2770,
)


_GETDETECTIONINSTANCEBBOXBYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceBboxByIdResponse',
  full_name='GetDetectionInstanceBboxByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_x', full_name='GetDetectionInstanceBboxByIdResponse.min_x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_x', full_name='GetDetectionInstanceBboxByIdResponse.max_x', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_y', full_name='GetDetectionInstanceBboxByIdResponse.min_y', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_y', full_name='GetDetectionInstanceBboxByIdResponse.max_y', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category_id', full_name='GetDetectionInstanceBboxByIdResponse.category_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=2891,
)


_GETDETECTIONINSTANCESTATEBYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceStateByIdRequest',
  full_name='GetDetectionInstanceStateByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceStateByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2893,
  serialized_end=2979,
)


_GETDETECTIONINSTANCESTATEBYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceStateByIdResponse',
  full_name='GetDetectionInstanceStateByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetDetectionInstanceStateByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceStateByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2981,
  serialized_end=3102,
)


_GETDETECTIONINSTANCEBYIDREQUEST = _descriptor.Descriptor(
  name='GetDetectionInstanceByIdRequest',
  full_name='GetDetectionInstanceByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceByIdRequest.detection_instance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3104,
  serialized_end=3185,
)


_GETDETECTIONINSTANCEBYIDRESPONSE = _descriptor.Descriptor(
  name='GetDetectionInstanceByIdResponse',
  full_name='GetDetectionInstanceByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='GetDetectionInstanceByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='GetDetectionInstanceByIdResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3187,
  serialized_end=3303,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsViaHumanRequest',
  full_name='UpdateDetectionInstanceGeoPointsViaHumanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='UpdateDetectionInstanceGeoPointsViaHumanRequest.detection_instance_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='UpdateDetectionInstanceGeoPointsViaHumanRequest.geo_point_shadow_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='UpdateDetectionInstanceGeoPointsViaHumanRequest.geo_point_shadow_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3306,
  serialized_end=3470,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsViaHumanResponse',
  full_name='UpdateDetectionInstanceGeoPointsViaHumanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoPointsViaHumanResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoPointsViaHumanResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3473,
  serialized_end=3605,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsViaMachineRequest',
  full_name='UpdateDetectionInstanceGeoPointsViaMachineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_instance_id', full_name='UpdateDetectionInstanceGeoPointsViaMachineRequest.detection_instance_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_start', full_name='UpdateDetectionInstanceGeoPointsViaMachineRequest.geo_point_shadow_start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_point_shadow_end', full_name='UpdateDetectionInstanceGeoPointsViaMachineRequest.geo_point_shadow_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3774,
)


_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE = _descriptor.Descriptor(
  name='UpdateDetectionInstanceGeoPointsViaMachineResponse',
  full_name='UpdateDetectionInstanceGeoPointsViaMachineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateDetectionInstanceGeoPointsViaMachineResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detection_instance', full_name='UpdateDetectionInstanceGeoPointsViaMachineResponse.detection_instance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3777,
  serialized_end=3911,
)

_DETECTIONINSTANCE.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_DETECTIONINSTANCE.fields_by_name['detected_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_DETECTIONINSTANCE.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST.fields_by_name['detection'].message_type = fsai__grpc__api_dot_protos_dot_detection__api__pb2._DETECTION
_FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST.fields_by_name['detection'].message_type = fsai__grpc__api_dot_protos_dot_detection__api__pb2._DETECTION
_FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESBYIMAGEIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE.fields_by_name['detection_instances'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_DELETEDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEDATABYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATEREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_TRANSITIONDETECTIONINSTANCESTATERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEBBOXBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESTATEBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCESTATEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETDETECTIONINSTANCESTATEBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEBYIDREQUEST.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_GETDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_GETDETECTIONINSTANCEBYIDRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST.fields_by_name['geo_point_shadow_start'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST.fields_by_name['geo_point_shadow_end'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOPOINT
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE.fields_by_name['detection_instance'].message_type = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['DetectionInstance'] = _DETECTIONINSTANCE
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByImageIdRequest'] = _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST
DESCRIPTOR.message_types_by_name['CacheDetectionInstancesDataByImageIdResponse'] = _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceViaHumanRequest'] = _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceViaHumanResponse'] = _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceViaMachineRequest'] = _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateDetectionInstanceViaMachineResponse'] = _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByImageIdRequest'] = _GETDETECTIONINSTANCESBYIMAGEIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstancesByImageIdResponse'] = _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxViaHumanRequest'] = _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxViaHumanResponse'] = _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxViaMachineRequest'] = _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoBboxViaMachineResponse'] = _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdRequest'] = _DELETEDETECTIONINSTANCEBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteDetectionInstanceByIdResponse'] = _DELETEDETECTIONINSTANCEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdRequest'] = _GETDETECTIONINSTANCEDATABYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceDataByIdResponse'] = _GETDETECTIONINSTANCEDATABYIDRESPONSE
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateRequest'] = _TRANSITIONDETECTIONINSTANCESTATEREQUEST
DESCRIPTOR.message_types_by_name['TransitionDetectionInstanceStateResponse'] = _TRANSITIONDETECTIONINSTANCESTATERESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdRequest'] = _GETDETECTIONINSTANCEBBOXBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceBboxByIdResponse'] = _GETDETECTIONINSTANCEBBOXBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceStateByIdRequest'] = _GETDETECTIONINSTANCESTATEBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceStateByIdResponse'] = _GETDETECTIONINSTANCESTATEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['GetDetectionInstanceByIdRequest'] = _GETDETECTIONINSTANCEBYIDREQUEST
DESCRIPTOR.message_types_by_name['GetDetectionInstanceByIdResponse'] = _GETDETECTIONINSTANCEBYIDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsViaHumanRequest'] = _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsViaHumanResponse'] = _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsViaMachineRequest'] = _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDetectionInstanceGeoPointsViaMachineResponse'] = _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectionInstance = _reflection.GeneratedProtocolMessageType('DetectionInstance', (_message.Message,), {
  'DESCRIPTOR' : _DETECTIONINSTANCE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DetectionInstance)
  })
_sym_db.RegisterMessage(DetectionInstance)

CacheDetectionInstancesDataByImageIdRequest = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByImageIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByImageIdRequest)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByImageIdRequest)

CacheDetectionInstancesDataByImageIdResponse = _reflection.GeneratedProtocolMessageType('CacheDetectionInstancesDataByImageIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:CacheDetectionInstancesDataByImageIdResponse)
  })
_sym_db.RegisterMessage(CacheDetectionInstancesDataByImageIdResponse)

FindOrCreateDetectionInstanceViaHumanRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceViaHumanRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceViaHumanRequest)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceViaHumanRequest)

FindOrCreateDetectionInstanceViaHumanResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceViaHumanResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceViaHumanResponse)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceViaHumanResponse)

FindOrCreateDetectionInstanceViaMachineRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceViaMachineRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceViaMachineRequest)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceViaMachineRequest)

FindOrCreateDetectionInstanceViaMachineResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateDetectionInstanceViaMachineResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateDetectionInstanceViaMachineResponse)
  })
_sym_db.RegisterMessage(FindOrCreateDetectionInstanceViaMachineResponse)

GetDetectionInstancesByImageIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByImageIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYIMAGEIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByImageIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByImageIdRequest)

GetDetectionInstancesByImageIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstancesByImageIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESBYIMAGEIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstancesByImageIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstancesByImageIdResponse)

UpdateDetectionInstanceGeoBboxViaHumanRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxViaHumanRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxViaHumanRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxViaHumanRequest)

UpdateDetectionInstanceGeoBboxViaHumanResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxViaHumanResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxViaHumanResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxViaHumanResponse)

UpdateDetectionInstanceGeoBboxViaMachineRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxViaMachineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxViaMachineRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxViaMachineRequest)

UpdateDetectionInstanceGeoBboxViaMachineResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoBboxViaMachineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoBboxViaMachineResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoBboxViaMachineResponse)

DeleteDetectionInstanceByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdRequest)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdRequest)

DeleteDetectionInstanceByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteDetectionInstanceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDETECTIONINSTANCEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteDetectionInstanceByIdResponse)
  })
_sym_db.RegisterMessage(DeleteDetectionInstanceByIdResponse)

GetDetectionInstanceDataByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdRequest)

GetDetectionInstanceDataByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceDataByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEDATABYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceDataByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceDataByIdResponse)

TransitionDetectionInstanceStateRequest = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateRequest)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateRequest)

TransitionDetectionInstanceStateResponse = _reflection.GeneratedProtocolMessageType('TransitionDetectionInstanceStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONDETECTIONINSTANCESTATERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:TransitionDetectionInstanceStateResponse)
  })
_sym_db.RegisterMessage(TransitionDetectionInstanceStateResponse)

GetDetectionInstanceBboxByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdRequest)

GetDetectionInstanceBboxByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceBboxByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceBboxByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceBboxByIdResponse)

GetDetectionInstanceStateByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceStateByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESTATEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceStateByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceStateByIdRequest)

GetDetectionInstanceStateByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceStateByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCESTATEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceStateByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceStateByIdResponse)

GetDetectionInstanceByIdRequest = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceByIdRequest)
  })
_sym_db.RegisterMessage(GetDetectionInstanceByIdRequest)

GetDetectionInstanceByIdResponse = _reflection.GeneratedProtocolMessageType('GetDetectionInstanceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETECTIONINSTANCEBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDetectionInstanceByIdResponse)
  })
_sym_db.RegisterMessage(GetDetectionInstanceByIdResponse)

UpdateDetectionInstanceGeoPointsViaHumanRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsViaHumanRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsViaHumanRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsViaHumanRequest)

UpdateDetectionInstanceGeoPointsViaHumanResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsViaHumanResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsViaHumanResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsViaHumanResponse)

UpdateDetectionInstanceGeoPointsViaMachineRequest = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsViaMachineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsViaMachineRequest)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsViaMachineRequest)

UpdateDetectionInstanceGeoPointsViaMachineResponse = _reflection.GeneratedProtocolMessageType('UpdateDetectionInstanceGeoPointsViaMachineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE,
  '__module__' : 'fsai_grpc_api.protos.detection_instance_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDetectionInstanceGeoPointsViaMachineResponse)
  })
_sym_db.RegisterMessage(UpdateDetectionInstanceGeoPointsViaMachineResponse)



_DETECTIONINSTANCEAPI = _descriptor.ServiceDescriptor(
  name='DetectionInstanceApi',
  full_name='DetectionInstanceApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3914,
  serialized_end=5705,
  methods=[
  _descriptor.MethodDescriptor(
    name='CacheDetectionInstancesDataByImageId',
    full_name='DetectionInstanceApi.CacheDetectionInstancesDataByImageId',
    index=0,
    containing_service=None,
    input_type=_CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST,
    output_type=_CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDetectionInstanceById',
    full_name='DetectionInstanceApi.DeleteDetectionInstanceById',
    index=1,
    containing_service=None,
    input_type=_DELETEDETECTIONINSTANCEBYIDREQUEST,
    output_type=_DELETEDETECTIONINSTANCEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateDetectionInstanceViaHuman',
    full_name='DetectionInstanceApi.FindOrCreateDetectionInstanceViaHuman',
    index=2,
    containing_service=None,
    input_type=_FINDORCREATEDETECTIONINSTANCEVIAHUMANREQUEST,
    output_type=_FINDORCREATEDETECTIONINSTANCEVIAHUMANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindOrCreateDetectionInstanceViaMachine',
    full_name='DetectionInstanceApi.FindOrCreateDetectionInstanceViaMachine',
    index=3,
    containing_service=None,
    input_type=_FINDORCREATEDETECTIONINSTANCEVIAMACHINEREQUEST,
    output_type=_FINDORCREATEDETECTIONINSTANCEVIAMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceDataById',
    full_name='DetectionInstanceApi.GetDetectionInstanceDataById',
    index=4,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEDATABYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEDATABYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceBboxById',
    full_name='DetectionInstanceApi.GetDetectionInstanceBboxById',
    index=5,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEBBOXBYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEBBOXBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceStateById',
    full_name='DetectionInstanceApi.GetDetectionInstanceStateById',
    index=6,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCESTATEBYIDREQUEST,
    output_type=_GETDETECTIONINSTANCESTATEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstanceById',
    full_name='DetectionInstanceApi.GetDetectionInstanceById',
    index=7,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCEBYIDREQUEST,
    output_type=_GETDETECTIONINSTANCEBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDetectionInstancesByImageId',
    full_name='DetectionInstanceApi.GetDetectionInstancesByImageId',
    index=8,
    containing_service=None,
    input_type=_GETDETECTIONINSTANCESBYIMAGEIDREQUEST,
    output_type=_GETDETECTIONINSTANCESBYIMAGEIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransitionDetectionInstanceState',
    full_name='DetectionInstanceApi.TransitionDetectionInstanceState',
    index=9,
    containing_service=None,
    input_type=_TRANSITIONDETECTIONINSTANCESTATEREQUEST,
    output_type=_TRANSITIONDETECTIONINSTANCESTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoBboxViaHuman',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoBboxViaHuman',
    index=10,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOBBOXVIAHUMANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoBboxViaMachine',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoBboxViaMachine',
    index=11,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINEREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOBBOXVIAMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoPointsViaHuman',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoPointsViaHuman',
    index=12,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOPOINTSVIAHUMANRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDetectionInstanceGeoPointsViaMachine',
    full_name='DetectionInstanceApi.UpdateDetectionInstanceGeoPointsViaMachine',
    index=13,
    containing_service=None,
    input_type=_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINEREQUEST,
    output_type=_UPDATEDETECTIONINSTANCEGEOPOINTSVIAMACHINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTIONINSTANCEAPI)

DESCRIPTOR.services_by_name['DetectionInstanceApi'] = _DETECTIONINSTANCEAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import detection_instance_api_pb2 as fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2


class DetectionInstanceApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CacheDetectionInstancesDataByImageId = channel.unary_unary(
                '/DetectionInstanceApi/CacheDetectionInstancesDataByImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdResponse.FromString,
                )
        self.DeleteDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/DeleteDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
                )
        self.FindOrCreateDetectionInstanceViaHuman = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateDetectionInstanceViaHuman',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanResponse.FromString,
                )
        self.FindOrCreateDetectionInstanceViaMachine = channel.unary_unary(
                '/DetectionInstanceApi/FindOrCreateDetectionInstanceViaMachine',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineResponse.FromString,
                )
        self.GetDetectionInstanceDataById = channel.unary_stream(
                '/DetectionInstanceApi/GetDetectionInstanceDataById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
                )
        self.GetDetectionInstanceBboxById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceBboxById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
                )
        self.GetDetectionInstanceStateById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceStateById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdResponse.FromString,
                )
        self.GetDetectionInstanceById = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstanceById',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdResponse.FromString,
                )
        self.GetDetectionInstancesByImageId = channel.unary_unary(
                '/DetectionInstanceApi/GetDetectionInstancesByImageId',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
                )
        self.TransitionDetectionInstanceState = channel.unary_unary(
                '/DetectionInstanceApi/TransitionDetectionInstanceState',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBboxViaHuman = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBboxViaHuman',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoBboxViaMachine = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoBboxViaMachine',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoPointsViaHuman = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoPointsViaHuman',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanResponse.FromString,
                )
        self.UpdateDetectionInstanceGeoPointsViaMachine = channel.unary_unary(
                '/DetectionInstanceApi/UpdateDetectionInstanceGeoPointsViaMachine',
                request_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineResponse.FromString,
                )


class DetectionInstanceApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CacheDetectionInstancesDataByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateDetectionInstanceViaHuman(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOrCreateDetectionInstanceViaMachine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceDataById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceBboxById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceStateById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstanceById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDetectionInstancesByImageId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransitionDetectionInstanceState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBboxViaHuman(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoBboxViaMachine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoPointsViaHuman(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDetectionInstanceGeoPointsViaMachine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DetectionInstanceApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CacheDetectionInstancesDataByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheDetectionInstancesDataByImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdResponse.SerializeToString,
            ),
            'DeleteDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.SerializeToString,
            ),
            'FindOrCreateDetectionInstanceViaHuman': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateDetectionInstanceViaHuman,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanResponse.SerializeToString,
            ),
            'FindOrCreateDetectionInstanceViaMachine': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateDetectionInstanceViaMachine,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineResponse.SerializeToString,
            ),
            'GetDetectionInstanceDataById': grpc.unary_stream_rpc_method_handler(
                    servicer.GetDetectionInstanceDataById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.SerializeToString,
            ),
            'GetDetectionInstanceBboxById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceBboxById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.SerializeToString,
            ),
            'GetDetectionInstanceStateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceStateById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdResponse.SerializeToString,
            ),
            'GetDetectionInstanceById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstanceById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdResponse.SerializeToString,
            ),
            'GetDetectionInstancesByImageId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetectionInstancesByImageId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.SerializeToString,
            ),
            'TransitionDetectionInstanceState': grpc.unary_unary_rpc_method_handler(
                    servicer.TransitionDetectionInstanceState,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBboxViaHuman': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBboxViaHuman,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoBboxViaMachine': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoBboxViaMachine,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoPointsViaHuman': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoPointsViaHuman,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanResponse.SerializeToString,
            ),
            'UpdateDetectionInstanceGeoPointsViaMachine': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDetectionInstanceGeoPointsViaMachine,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DetectionInstanceApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DetectionInstanceApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CacheDetectionInstancesDataByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/CacheDetectionInstancesDataByImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.CacheDetectionInstancesDataByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/DeleteDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.DeleteDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateDetectionInstanceViaHuman(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateDetectionInstanceViaHuman',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaHumanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindOrCreateDetectionInstanceViaMachine(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/FindOrCreateDetectionInstanceViaMachine',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.FindOrCreateDetectionInstanceViaMachineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceDataById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DetectionInstanceApi/GetDetectionInstanceDataById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceDataByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceBboxById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceBboxById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceBboxByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceStateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceStateById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceStateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstanceById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstanceById',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstanceByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDetectionInstancesByImageId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/GetDetectionInstancesByImageId',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.GetDetectionInstancesByImageIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransitionDetectionInstanceState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/TransitionDetectionInstanceState',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.TransitionDetectionInstanceStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBboxViaHuman(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBboxViaHuman',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaHumanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoBboxViaMachine(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoBboxViaMachine',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoBboxViaMachineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoPointsViaHuman(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoPointsViaHuman',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaHumanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDetectionInstanceGeoPointsViaMachine(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DetectionInstanceApi/UpdateDetectionInstanceGeoPointsViaMachine',
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_detection__instance__api__pb2.UpdateDetectionInstanceGeoPointsViaMachineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
